summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KRegExpEditorInterface.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KRegExpEditorInterface.java')
-rw-r--r--kdejava/koala/org/kde/koala/KRegExpEditorInterface.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdejava/koala/org/kde/koala/KRegExpEditorInterface.java b/kdejava/koala/org/kde/koala/KRegExpEditorInterface.java
index 8742f6c3..e28a582e 100644
--- a/kdejava/koala/org/kde/koala/KRegExpEditorInterface.java
+++ b/kdejava/koala/org/kde/koala/KRegExpEditorInterface.java
@@ -7,10 +7,10 @@ import org.kde.qt.QtSupport;
/**
A graphical editor for regular expressions.
- The actual editor is located in kdeutils, with an interface in
- kdelibs. This means that it is a bit more complicated to create an
+ The actual editor is located in tdeutils, with an interface in
+ tdelibs. This means that it is a bit more complicated to create an
instance of the editor, but only a little bit more complicated.
- To check if kregexpeditor in kdeutils is installed and available use this line:
+ To check if kregexpeditor in tdeutils is installed and available use this line:
<pre>
boolean installed=!KTrader.self().query("KRegExpEditor/KRegExpEditor").isEmpty();
</pre>
@@ -19,7 +19,7 @@ import org.kde.qt.QtSupport;
<pre>
QDialog editorDialog = KParts.ComponentFactory.createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor" );
if ( editorDialog ) {
// kdeutils was installed, so the dialog was found fetch the editor interface
KRegExpEditorInterface editor = (KRegExpEditorInterface)( editorDialog.qt_cast( "KRegExpEditorInterface" ) );
Q_ASSERT( editor ); // This should not fail!
// now use the editor.
@@ -42,7 +42,7 @@ import org.kde.qt.QtSupport;
KParts.ComponentFactory.createInstanceFromQuery<QWidget>(
"KRegExpEditor/KRegExpEditor", null, parent );
if ( editorWidget ) {
// kdeutils was installed, so the widget was found fetch the editor interface
KRegExpEditorInterface editor = (KRegExpEditorInterface)( editorWidget.qt_cast( "KRegExpEditorInterface" ) );
Q_ASSERT( editor ); // This should not fail!
// now use the editor.
@@ -19,7 +19,7 @@ import org.kde.qt.QtSupport;
QDialog editorDialog = KParts.ComponentFactory.createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor" );
if ( editorDialog ) {
- // kdeutils was installed, so the dialog was found fetch the editor interface
+ // tdeutils was installed, so the dialog was found fetch the editor interface
KRegExpEditorInterface editor = (KRegExpEditorInterface)( editorDialog.qt_cast( "KRegExpEditorInterface" ) );
Q_ASSERT( editor ); // This should not fail!
@@ -42,7 +42,7 @@ import org.kde.qt.QtSupport;
"KRegExpEditor/KRegExpEditor", null, parent );
if ( editorWidget ) {
- // kdeutils was installed, so the widget was found fetch the editor interface
+ // tdeutils was installed, so the widget was found fetch the editor interface
KRegExpEditorInterface editor = (KRegExpEditorInterface)( editorWidget.qt_cast( "KRegExpEditorInterface" ) );
Q_ASSERT( editor ); // This should not fail!